==> solr-core-4.3.0-sources.jar: org/apache/solr/search/OldLuceneQParserPlugin.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.search;

import org.apache.solr.common.params.SolrParams;
import org.apache.solr.common.util.NamedList;
import org.apache.solr.request.SolrQueryRequest;

/**
 * Parse Solr's variant of Lucene QueryParser syntax, including the
 * deprecated sort specification after the query.
 * <br>Example: <code>{!lucenePlusSort}myfield:foo +bar -baz;price asc</code>
 */
public class OldLuceneQParserPlugin extends QParserPlugin {
  public static String NAME = "lucenePlusSort";

  @Override
  public void init(NamedList args) {
  }

  @Override
  public QParser createParser(String qstr, SolrParams localParams, SolrParams params, SolrQueryRequest req) {
    return new OldLuceneQParser(qstr, localParams, params, req);
  }
}

==> solr-core-4.9.0-sources.jar: org/apache/solr/search/OldLuceneQParserPlugin.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.search;

import org.apache.solr.common.params.SolrParams;
import org.apache.solr.common.util.NamedList;
import org.apache.solr.request.SolrQueryRequest;

/**
 * Parse Solr's variant of Lucene QueryParser syntax, including the
 * deprecated sort specification after the query.
 * <br>Example: <code>{!lucenePlusSort}myfield:foo +bar -baz;price asc</code>
 */
public class OldLuceneQParserPlugin extends QParserPlugin {
  public static final String NAME = "lucenePlusSort";

  @Override
  public void init(NamedList args) {
  }

  @Override
  public QParser createParser(String qstr, SolrParams localParams, SolrParams params, SolrQueryRequest req) {
    return new OldLuceneQParser(qstr, localParams, params, req);
  }
}
